@@ -276,7 +276,7 @@ class FacileToolkit2:
                                     x).is_displayed()]
         if not_visible_elements:
             errors = ', '.join(not_visible_elements)
-            raise AssertionError("Following elements are not visible: %s" % errors)
+            BuiltIn().run_keyword_and_ignore_error("Should Be Empty", errors, "Following elements are not visible: %s" % errors)
 
     @keyword
     def i_dont_see(self, *locators):
@@ -290,7 +290,7 @@ class FacileToolkit2:
                                 x).is_displayed()]
         if visible_elements:
             errors = ', '.join(visible_elements)
-            raise AssertionError("Following elements are visible: %s" % errors)
+            BuiltIn().run_keyword_and_ignore_error("Should Be Empty", errors, "Following elements are visible: %s" % errors)
 
     @keyword
     def select_first_autocomplete_option(self,
